from __future__ import annotations

from typing import TYPE_CHECKING, Any

from ..types import ChatIdUnion, InlineKeyboardMarkup, InputMediaUnion, Message
from .base import TelegramMethod


class EditMessageMedia(TelegramMethod[Message | bool]):
    """
    Use this method to edit animation, audio, document, live photo, photo, or video messages, or to replace a text or a rich message with a media. If a message is part of a message album, then it can be edited only to an audio for audio albums, only to a document for document albums and to a photo, a live photo, or a video otherwise. When an inline message is edited, a new file can't be uploaded; use a previously uploaded file via its file_id or specify a URL. On success, if the edited message is not an inline message, the edited :class:`aiogram.types.message.Message` is returned, otherwise :code:`True` is returned. Note that business messages that were not sent by the bot and do not contain an inline keyboard can only be edited within **48 hours** from the time they were sent.

    Source: https://core.telegram.org/bots/api#editmessagemedia
    """

    __returning__ = Message | bool
    __api_method__ = "editMessageMedia"

    media: InputMediaUnion
    """A JSON-serialized object for a new media content of the message"""
    business_connection_id: str | None = None
    """Unique identifier of the business connection on behalf of which the message to be edited was sent"""
    chat_id: ChatIdUnion | None = None
    """Required if *inline_message_id* is not specified. Unique identifier for the target chat or username of the target bot, supergroup or channel in the format :code:`@username`"""
    message_id: int | None = None
    """Required if *inline_message_id* is not specified. Identifier of the message to edit"""
    inline_message_id: str | None = None
    """Required if *chat_id* and *message_id* are not specified. Identifier of the inline message"""
    reply_markup: InlineKeyboardMarkup | None = None
    """A JSON-serialized object for a new `inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            media: InputMediaUnion,
            business_connection_id: str | None = None,
            chat_id: ChatIdUnion | None = None,
            message_id: int | None = None,
            inline_message_id: str | None = None,
            reply_markup: InlineKeyboardMarkup | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                media=media,
                business_connection_id=business_connection_id,
                chat_id=chat_id,
                message_id=message_id,
                inline_message_id=inline_message_id,
                reply_markup=reply_markup,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .background_fill_freeform_gradient import BackgroundFillFreeformGradient
from .background_fill_gradient import BackgroundFillGradient
from .background_fill_solid import BackgroundFillSolid

BackgroundFillUnion: TypeAlias = Annotated[
    BackgroundFillSolid | BackgroundFillGradient | BackgroundFillFreeformGradient,
    Field(discriminator="type"),
]



from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichTextType
from .base import TelegramObject
from .rich_text import RichText


class RichTextCustomEmoji(RichText):
    """
    A custom emoji.

    Source: https://core.telegram.org/bots/api#richtextcustomemoji
    """

    type: Literal[RichTextType.CUSTOM_EMOJI] = RichTextType.CUSTOM_EMOJI
    """Type of the rich text, always 'custom_emoji'"""
    custom_emoji_id: str
    """Unique identifier of the custom emoji. Use :class:`aiogram.methods.get_custom_emoji_stickers.GetCustomEmojiStickers` to get full information about the sticker"""
    alternative_text: str
    """Alternative emoji for the custom emoji"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichTextType.CUSTOM_EMOJI] = RichTextType.CUSTOM_EMOJI,
            custom_emoji_id: str,
            alternative_text: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                custom_emoji_id=custom_emoji_id,
                alternative_text=alternative_text,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .reaction_type_custom_emoji import ReactionTypeCustomEmoji
from .reaction_type_emoji import ReactionTypeEmoji
from .reaction_type_paid import ReactionTypePaid

ReactionTypeUnion: TypeAlias = Annotated[
    ReactionTypeEmoji | ReactionTypeCustomEmoji | ReactionTypePaid, Field(discriminator="type")
]



from typing import Annotated, TypeAlias

from pydantic import Field

from .input_profile_photo_animated import InputProfilePhotoAnimated
from .input_profile_photo_static import InputProfilePhotoStatic

InputProfilePhotoUnion: TypeAlias = Annotated[
    InputProfilePhotoStatic | InputProfilePhotoAnimated, Field(discriminator="type")
]



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .rich_text import RichText
    from .rich_text_union import RichTextUnion


class RichBlockCaption(TelegramObject):
    """
    Caption of a rich formatted block.

    Source: https://core.telegram.org/bots/api#richblockcaption
    """

    text: RichTextUnion
    """Block caption"""
    credit: RichTextUnion | None = None
    """*Optional*. Block credit which corresponds to the HTML tag <cite>"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            text: RichTextUnion,
            credit: RichTextUnion | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(text=text, credit=credit, **__pydantic_kwargs)



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_text import RichText
    from .rich_text_union import RichTextUnion


class RichBlockThinking(RichBlock):
    """
    A block with a 'Thinking…' placeholder, corresponding to the custom HTML tag :code:`<tg-thinking>`. The block may be used only in :class:`aiogram.methods.send_rich_message_draft.SendRichMessageDraft`, therefore it can't be received in messages. See `https://t.me/addemoji/AIActions <https://t.me/addemoji/AIActions>`_`https://t.me/addemoji/AIActions <https://t.me/addemoji/AIActions>`_ for examples of custom emoji, which are recommended for usage in the block.

    Source: https://core.telegram.org/bots/api#richblockthinking
    """

    type: Literal[RichBlockType.THINKING] = RichBlockType.THINKING
    """Type of the block, always 'thinking'"""
    text: RichTextUnion
    """Text of the block. See `https://t.me/addemoji/AIActions <https://t.me/addemoji/AIActions>`_`https://t.me/addemoji/AIActions <https://t.me/addemoji/AIActions>`_ for examples of custom emoji, which are recommended for usage in the block"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.THINKING] = RichBlockType.THINKING,
            text: RichTextUnion,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(type=type, text=text, **__pydantic_kwargs)



from typing import TYPE_CHECKING, Any

from aiogram.methods import TelegramMethod

from ..types import ChatIdUnion


class UnpinAllGeneralForumTopicMessages(TelegramMethod[bool]):
    """
    Use this method to clear the list of pinned messages in a General forum topic. The bot must be an administrator in the chat for this to work and must have the *can_pin_messages* administrator right in the supergroup. Returns :code:`True` on success.

    Source: https://core.telegram.org/bots/api#unpinallgeneralforumtopicmessages
    """

    __returning__ = bool
    __api_method__ = "unpinAllGeneralForumTopicMessages"

    chat_id: ChatIdUnion
    """Unique identifier for the target chat or username of the target supergroup in the format :code:`@username`"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__, *, chat_id: ChatIdUnion, **__pydantic_kwargs: Any
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(chat_id=chat_id, **__pydantic_kwargs)



from typing import TYPE_CHECKING, Any

from .base import TelegramObject


class InputRichMessage(TelegramObject):
    """
    Describes a rich message to be sent. Exactly **one** of the fields *html* or *markdown* must be used.

    Source: https://core.telegram.org/bots/api#inputrichmessage
    """

    html: str | None = None
    """*Optional*. Content of the rich message to send described using HTML formatting. See `rich message formatting options <https://core.telegram.org/bots/api#rich-message-formatting-options>`_ for more details"""
    markdown: str | None = None
    """*Optional*. Content of the rich message to send described using Markdown formatting. See `rich message formatting options <https://core.telegram.org/bots/api#rich-message-formatting-options>`_ for more details"""
    is_rtl: bool | None = None
    """*Optional*. Pass :code:`True` if the rich message must be shown right-to-left"""
    skip_entity_detection: bool | None = None
    """*Optional*. Pass :code:`True` to skip automatic detection of entities (e.g., URLs, email addresses, username mentions, hashtags, cashtags, bot commands, or phone numbers) in the text"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            html: str | None = None,
            markdown: str | None = None,
            is_rtl: bool | None = None,
            skip_entity_detection: bool | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                html=html,
                markdown=markdown,
                is_rtl=is_rtl,
                skip_entity_detection=skip_entity_detection,
                **__pydantic_kwargs,
            )



from typing import TYPE_CHECKING, Any

from .base import TelegramMethod


class SendChatJoinRequestWebApp(TelegramMethod[bool]):
    """
    Use this method to process a received chat join request query by showing a Mini App to the user before deciding the outcome. Returns :code:`True` on success.

    Source: https://core.telegram.org/bots/api#sendchatjoinrequestwebapp
    """

    __returning__ = bool
    __api_method__ = "sendChatJoinRequestWebApp"

    chat_join_request_query_id: str
    """Unique identifier of the join request query"""
    web_app_url: str
    """The URL of the Mini App to be opened"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            chat_join_request_query_id: str,
            web_app_url: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                chat_join_request_query_id=chat_join_request_query_id,
                web_app_url=web_app_url,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .menu_button_commands import MenuButtonCommands
from .menu_button_default import MenuButtonDefault
from .menu_button_web_app import MenuButtonWebApp

MenuButtonUnion: TypeAlias = Annotated[
    MenuButtonCommands | MenuButtonWebApp | MenuButtonDefault, Field(discriminator="type")
]



from .base import TelegramObject


class RichText(TelegramObject):
    """
    This object represents a rich formatted text. Currently, it can be either a String for plain text, an Array of :class:`aiogram.types.rich_text.RichText`, or any of the following types:

     - :class:`aiogram.types.rich_text_bold.RichTextBold`
     - :class:`aiogram.types.rich_text_italic.RichTextItalic`
     - :class:`aiogram.types.rich_text_underline.RichTextUnderline`
     - :class:`aiogram.types.rich_text_strikethrough.RichTextStrikethrough`
     - :class:`aiogram.types.rich_text_spoiler.RichTextSpoiler`
     - :class:`aiogram.types.rich_text_date_time.RichTextDateTime`
     - :class:`aiogram.types.rich_text_text_mention.RichTextTextMention`
     - :class:`aiogram.types.rich_text_subscript.RichTextSubscript`
     - :class:`aiogram.types.rich_text_superscript.RichTextSuperscript`
     - :class:`aiogram.types.rich_text_marked.RichTextMarked`
     - :class:`aiogram.types.rich_text_code.RichTextCode`
     - :class:`aiogram.types.rich_text_custom_emoji.RichTextCustomEmoji`
     - :class:`aiogram.types.rich_text_mathematical_expression.RichTextMathematicalExpression`
     - :class:`aiogram.types.rich_text_url.RichTextUrl`
     - :class:`aiogram.types.rich_text_email_address.RichTextEmailAddress`
     - :class:`aiogram.types.rich_text_phone_number.RichTextPhoneNumber`
     - :class:`aiogram.types.rich_text_bank_card_number.RichTextBankCardNumber`
     - :class:`aiogram.types.rich_text_mention.RichTextMention`
     - :class:`aiogram.types.rich_text_hashtag.RichTextHashtag`
     - :class:`aiogram.types.rich_text_cashtag.RichTextCashtag`
     - :class:`aiogram.types.rich_text_bot_command.RichTextBotCommand`
     - :class:`aiogram.types.rich_text_anchor.RichTextAnchor`
     - :class:`aiogram.types.rich_text_anchor_link.RichTextAnchorLink`
     - :class:`aiogram.types.rich_text_reference.RichTextReference`
     - :class:`aiogram.types.rich_text_reference_link.RichTextReferenceLink`

    Source: https://core.telegram.org/bots/api#richtext
    """



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichBlockType
from .base import TelegramObject
from .rich_block import RichBlock

if TYPE_CHECKING:
    from .rich_block_caption import RichBlockCaption
    from .video import Video


class RichBlockVideo(RichBlock):
    """
    A block with a video, corresponding to the HTML tag :code:`<video>`.

    Source: https://core.telegram.org/bots/api#richblockvideo
    """

    type: Literal[RichBlockType.VIDEO] = RichBlockType.VIDEO
    """Type of the block, always 'video'"""
    video: Video
    """The video"""
    has_spoiler: bool | None = None
    """*Optional*. :code:`True`, if the media preview is covered by a spoiler animation"""
    caption: RichBlockCaption | None = None
    """*Optional*. Caption of the block"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichBlockType.VIDEO] = RichBlockType.VIDEO,
            video: Video,
            has_spoiler: bool | None = None,
            caption: RichBlockCaption | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                video=video,
                has_spoiler=has_spoiler,
                caption=caption,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import Annotated, TypeAlias

from pydantic import Field

from .paid_media_live_photo import PaidMediaLivePhoto
from .paid_media_photo import PaidMediaPhoto
from .paid_media_preview import PaidMediaPreview
from .paid_media_video import PaidMediaVideo

PaidMediaUnion: TypeAlias = Annotated[
    PaidMediaLivePhoto | PaidMediaPhoto | PaidMediaPreview | PaidMediaVideo,
    Field(discriminator="type"),
]



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import RichTextType
from .base import TelegramObject
from .rich_text import RichText

if TYPE_CHECKING:
    from .rich_text import RichText
    from .rich_text_union import RichTextUnion


class RichTextDateTime(RichText):
    """
    Formatted date and time.

    Source: https://core.telegram.org/bots/api#richtextdatetime
    """

    type: Literal[RichTextType.DATE_TIME] = RichTextType.DATE_TIME
    """Type of the rich text, always 'date_time'"""
    text: RichTextUnion
    """The text"""
    unix_time: int
    """The Unix time associated with the entity"""
    date_time_format: str
    """The string that defines the formatting of the date and time. See `date-time entity formatting <https://core.telegram.org/bots/api#date-time-entity-formatting>`_ for more details"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[RichTextType.DATE_TIME] = RichTextType.DATE_TIME,
            text: RichTextUnion,
            unix_time: int,
            date_time_format: str,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                text=text,
                unix_time=unix_time,
                date_time_format=date_time_format,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, TypeAlias

from typing_extensions import TypeAliasType

from .rich_text_anchor import RichTextAnchor
from .rich_text_anchor_link import RichTextAnchorLink
from .rich_text_bank_card_number import RichTextBankCardNumber
from .rich_text_bold import RichTextBold
from .rich_text_bot_command import RichTextBotCommand
from .rich_text_cashtag import RichTextCashtag
from .rich_text_code import RichTextCode
from .rich_text_custom_emoji import RichTextCustomEmoji
from .rich_text_date_time import RichTextDateTime
from .rich_text_email_address import RichTextEmailAddress
from .rich_text_hashtag import RichTextHashtag
from .rich_text_italic import RichTextItalic
from .rich_text_marked import RichTextMarked
from .rich_text_mathematical_expression import RichTextMathematicalExpression
from .rich_text_mention import RichTextMention
from .rich_text_phone_number import RichTextPhoneNumber
from .rich_text_reference import RichTextReference
from .rich_text_reference_link import RichTextReferenceLink
from .rich_text_spoiler import RichTextSpoiler
from .rich_text_strikethrough import RichTextStrikethrough
from .rich_text_subscript import RichTextSubscript
from .rich_text_superscript import RichTextSuperscript
from .rich_text_text_mention import RichTextTextMention
from .rich_text_underline import RichTextUnderline
from .rich_text_url import RichTextUrl

if TYPE_CHECKING:
    RichTextUnion: TypeAlias = (
        str
        | list["RichTextUnion"]
        | RichTextBold
        | RichTextItalic
        | RichTextUnderline
        | RichTextStrikethrough
        | RichTextSpoiler
        | RichTextDateTime
        | RichTextTextMention
        | RichTextSubscript
        | RichTextSuperscript
        | RichTextMarked
        | RichTextCode
        | RichTextCustomEmoji
        | RichTextMathematicalExpression
        | RichTextUrl
        | RichTextEmailAddress
        | RichTextPhoneNumber
        | RichTextBankCardNumber
        | RichTextMention
        | RichTextHashtag
        | RichTextCashtag
        | RichTextBotCommand
        | RichTextAnchor
        | RichTextAnchorLink
        | RichTextReference
        | RichTextReferenceLink
    )
else:
    RichTextUnion = TypeAliasType(
        "RichTextUnion",
        str
        | list["RichTextUnion"]
        | RichTextBold
        | RichTextItalic
        | RichTextUnderline
        | RichTextStrikethrough
        | RichTextSpoiler
        | RichTextDateTime
        | RichTextTextMention
        | RichTextSubscript
        | RichTextSuperscript
        | RichTextMarked
        | RichTextCode
        | RichTextCustomEmoji
        | RichTextMathematicalExpression
        | RichTextUrl
        | RichTextEmailAddress
        | RichTextPhoneNumber
        | RichTextBankCardNumber
        | RichTextMention
        | RichTextHashtag
        | RichTextCashtag
        | RichTextBotCommand
        | RichTextAnchor
        | RichTextAnchorLink
        | RichTextReference
        | RichTextReferenceLink,
    )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .rich_block import RichBlock
    from .rich_block_union import RichBlockUnion


class RichBlockListItem(TelegramObject):
    """
    An item of a list.

    Source: https://core.telegram.org/bots/api#richblocklistitem
    """

    label: str
    """Label of the item"""
    blocks: list[RichBlockUnion]
    """The content of the item"""
    has_checkbox: bool | None = None
    """*Optional*. :code:`True`, if the item has a checkbox"""
    is_checked: bool | None = None
    """*Optional*. :code:`True`, if the item has a checked checkbox"""
    value: int | None = None
    """*Optional*. For ordered lists, the numeric value of the item label"""
    type: str | None = None
    """*Optional*. For ordered lists, the type of the item label; must be one of 'a' for lowercase letters, 'A' for uppercase letters, 'i' for lowercase Roman numerals, 'I' for uppercase Roman numerals, or '1' for decimal numbers"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            label: str,
            blocks: list[RichBlockUnion],
            has_checkbox: bool | None = None,
            is_checked: bool | None = None,
            value: int | None = None,
            type: str | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                label=label,
                blocks=blocks,
                has_checkbox=has_checkbox,
                is_checked=is_checked,
                value=value,
                type=type,
                **__pydantic_kwargs,
            )



from typing import Annotated, TypeAlias

from pydantic import Field

from .owned_gift_regular import OwnedGiftRegular
from .owned_gift_unique import OwnedGiftUnique

OwnedGiftUnion: TypeAlias = Annotated[
    OwnedGiftRegular | OwnedGiftUnique, Field(discriminator="type")
]



from typing import Annotated, TypeAlias

from pydantic import Field

from .rich_block_anchor import RichBlockAnchor
from .rich_block_animation import RichBlockAnimation
from .rich_block_audio import RichBlockAudio
from .rich_block_block_quotation import RichBlockBlockQuotation
from .rich_block_collage import RichBlockCollage
from .rich_block_details import RichBlockDetails
from .rich_block_divider import RichBlockDivider
from .rich_block_footer import RichBlockFooter
from .rich_block_list import RichBlockList
from .rich_block_map import RichBlockMap
from .rich_block_mathematical_expression import RichBlockMathematicalExpression
from .rich_block_paragraph import RichBlockParagraph
from .rich_block_photo import RichBlockPhoto
from .rich_block_preformatted import RichBlockPreformatted
from .rich_block_pull_quotation import RichBlockPullQuotation
from .rich_block_section_heading import RichBlockSectionHeading
from .rich_block_slideshow import RichBlockSlideshow
from .rich_block_table import RichBlockTable
from .rich_block_thinking import RichBlockThinking
from .rich_block_video import RichBlockVideo
from .rich_block_voice_note import RichBlockVoiceNote

RichBlockUnion: TypeAlias = Annotated[
    RichBlockParagraph
    | RichBlockSectionHeading
    | RichBlockPreformatted
    | RichBlockFooter
    | RichBlockDivider
    | RichBlockMathematicalExpression
    | RichBlockAnchor
    | RichBlockList
    | RichBlockBlockQuotation
    | RichBlockPullQuotation
    | RichBlockCollage
    | RichBlockSlideshow
    | RichBlockTable
    | RichBlockDetails
    | RichBlockMap
    | RichBlockAnimation
    | RichBlockAudio
    | RichBlockPhoto
    | RichBlockVideo
    | RichBlockVoiceNote
    | RichBlockThinking,
    Field(discriminator="type"),
]



from __future__ import annotations

from typing import TYPE_CHECKING, Any, Literal

from ..enums import InlineQueryResultType
from .inline_query_result import InlineQueryResult

if TYPE_CHECKING:
    from .inline_keyboard_markup import InlineKeyboardMarkup
    from .input_message_content_union import InputMessageContentUnion


class InlineQueryResultCachedSticker(InlineQueryResult):
    """
    Represents a link to a sticker stored on the Telegram servers. By default, this sticker will be sent by the user. Alternatively, you can use *input_message_content* to send a message with the specified content instead of the sticker.

    Source: https://core.telegram.org/bots/api#inlinequeryresultcachedsticker
    """

    type: Literal[InlineQueryResultType.STICKER] = InlineQueryResultType.STICKER
    """Type of the result, must be *sticker*"""
    id: str
    """Unique identifier for this result, 1-64 bytes"""
    sticker_file_id: str
    """A valid file identifier of the sticker"""
    reply_markup: InlineKeyboardMarkup | None = None
    """*Optional*. `Inline keyboard <https://core.telegram.org/bots/features#inline-keyboards>`_ attached to the message"""
    input_message_content: InputMessageContentUnion | None = None
    """*Optional*. Content of the message to be sent instead of the sticker"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            type: Literal[InlineQueryResultType.STICKER] = InlineQueryResultType.STICKER,
            id: str,
            sticker_file_id: str,
            reply_markup: InlineKeyboardMarkup | None = None,
            input_message_content: InputMessageContentUnion | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                type=type,
                id=id,
                sticker_file_id=sticker_file_id,
                reply_markup=reply_markup,
                input_message_content=input_message_content,
                **__pydantic_kwargs,
            )



from __future__ import annotations

from typing import TYPE_CHECKING, Any

from .base import TelegramObject

if TYPE_CHECKING:
    from .rich_text import RichText
    from .rich_text_union import RichTextUnion


class RichBlockTableCell(TelegramObject):
    """
    Cell in a table.

    Source: https://core.telegram.org/bots/api#richblocktablecell
    """

    align: str
    """Horizontal cell content alignment. Currently, must be one of 'left', 'center', or 'right'"""
    valign: str
    """Vertical cell content alignment. Currently, must be one of 'top', 'middle', or 'bottom'"""
    text: RichTextUnion | None = None
    """*Optional*. Text in the cell. If omitted, then the cell is invisible"""
    is_header: bool | None = None
    """*Optional*. :code:`True`, if the cell is a header cell"""
    colspan: int | None = None
    """*Optional*. The number of columns the cell spans if it is bigger than 1"""
    rowspan: int | None = None
    """*Optional*. The number of rows the cell spans if it is bigger than 1"""

    if TYPE_CHECKING:
        # DO NOT EDIT MANUALLY!!!
        # This section was auto-generated via `butcher`

        def __init__(
            __pydantic__self__,
            *,
            align: str,
            valign: str,
            text: RichTextUnion | None = None,
            is_header: bool | None = None,
            colspan: int | None = None,
            rowspan: int | None = None,
            **__pydantic_kwargs: Any,
        ) -> None:
            # DO NOT EDIT MANUALLY!!!
            # This method was auto-generated via `butcher`
            # Is needed only for type checking and IDE support without any additional plugins

            super().__init__(
                align=align,
                valign=valign,
                text=text,
                is_header=is_header,
                colspan=colspan,
                rowspan=rowspan,
                **__pydantic_kwargs,
            )



from enum import Enum


class RichTextType(str, Enum):
    """
    This object represents the rich text type.

    Source: https://core.telegram.org/bots/api#richtext
    """

    BOLD = "bold"
    ITALIC = "italic"
    UNDERLINE = "underline"
    STRIKETHROUGH = "strikethrough"
    SPOILER = "spoiler"
    DATE_TIME = "date_time"
    TEXT_MENTION = "text_mention"
    SUBSCRIPT = "subscript"
    SUPERSCRIPT = "superscript"
    MARKED = "marked"
    CODE = "code"
    CUSTOM_EMOJI = "custom_emoji"
    MATHEMATICAL_EXPRESSION = "mathematical_expression"
    URL = "url"
    EMAIL_ADDRESS = "email_address"
    PHONE_NUMBER = "phone_number"
    BANK_CARD_NUMBER = "bank_card_number"
    MENTION = "mention"
    HASHTAG = "hashtag"
    CASHTAG = "cashtag"
    BOT_COMMAND = "bot_command"
    ANCHOR = "anchor"
    ANCHOR_LINK = "anchor_link"
    REFERENCE = "reference"
    REFERENCE_LINK = "reference_link"
